@@ -1,6 +1,7 @@
 from typing import Any, Callable, Generic, TypeVar
 
 from alfort import Alfort, Dispatch, Enqueue, Init, Update, View
+from alfort.sub import Subscriptions
 from alfort.vdom import (
     Node,
     Patch,
@@ -27,14 +28,12 @@ def _default_enqueue(render: Callable[[], None]) -> None:
 class DomNode(Node, Generic[M]):
     dom: HTMLElement
     dispatch: Dispatch[M]
-    handlers: dict[str, Callable[[Any], None]]
+    handlers: dict[str, Callable[[Any], M]]
     listener: JsProxy
 
-    def __init__(
-        self, dom: HTMLElement, dispatch: Dispatch[M] = lambda _: None
-    ) -> None:
+    def __init__(self, dom: HTMLElement, dispatch: Dispatch[M] | None = None) -> None:
         self.dom = dom
-        self.dispatch = dispatch
+        self.dispatch = dispatch if dispatch is not None else lambda _: None
         self.handlers = {}
 
         def _listener(event: Any) -> None:
@@ -100,8 +99,9 @@ class AlfortDom(Alfort[S, M, DomNode[M]]):
         view: View[S],
         update: Update[M, S],
         enqueue: Enqueue = _default_enqueue,
+        subscriptions: Subscriptions[S, M] | None = None,
     ) -> None:
-        super().__init__(init, view, update, enqueue)
+        super().__init__(init, view, update, enqueue, subscriptions)
 
     def create_text(
         self,
